@@ -178,17 +178,17 @@ class sentence_tranformer_checker():
 
         if model is not None:
             try:
-                self.model = SentenceTransformer(model, device=device)
+                self.model = SentenceTransformer(model, device=self.device)
             except HTTPError:
                 raise HTTPError('entered model name is not defined')
         # if no model is provided use the default model
         else:
             print('initializing the model...')
             if lang.lower() == 'en':
-                self.model = SentenceTransformer('all-MiniLM-L6-v2', device=device)
+                self.model = SentenceTransformer('all-MiniLM-L6-v2', device=self.device)
                 print('done...')
             else:
-                self.model = SentenceTransformer('distiluse-base-multilingual-cased-v1', device=device)
+                self.model = SentenceTransformer('distiluse-base-multilingual-cased-v1', device=self.device)
                 print('done...')
 
         if encode_target:  
